module.exports = defineTest({
	description: 'deoptimizes typeof for regular expressions to better support es6-sim'
});
